import { CredentialsInput } from 'helpers/validate-credentials';
export interface DeleteUserInput extends CredentialsInput {
    userName: string;
}
/**
 * Deletes an IAM user. The full logic involved when deleting a user is discussed here:
 *
 * https://docs.aws.amazon.com/AWSJavaScriptSDK/v3/latest/clients/client-iam/classes/deleteusercommand.html
 * https://docs.aws.amazon.com/IAM/latest/UserGuide/id_users_manage.html#id_users_deleting
 * https://docs.aws.amazon.com/IAM/latest/APIReference/API_DeleteUser.html
 *
 * For this application, we only address the following:
 *
 * - login profile
 * - access keys
 * - inline policies
 * - attached policies
 * - group memberships
 *
 */
export declare function deleteUser({ accessKey, secretKey, region, userName }: DeleteUserInput): Promise<void>;
