var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
import { IAMClient, ListUsersCommand } from '@aws-sdk/client-iam';
/**
 * Returns a list of IAM users matching the given path prefix
 */
export function listUsers({ accessKey, secretKey, region, pathPrefix }) {
    return __awaiter(this, void 0, void 0, function* () {
        const client = new IAMClient({
            region,
            credentials: {
                accessKeyId: accessKey,
                secretAccessKey: secretKey,
            },
        });
        const params = {
            PathPrefix: pathPrefix,
            MaxItems: 1000,
        };
        let data;
        const users = [];
        do {
            data = yield client.send(new ListUsersCommand(params));
            params.Marker = data.Marker;
            if (data.Users && data.Users.length > 0)
                users.push(...data.Users);
        } while (data.IsTruncated);
        return users;
    });
}
//# sourceMappingURL=listUsers.js.map