var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
import { SecretsManagerClient, GetSecretValueCommand, } from '@aws-sdk/client-secrets-manager';
/**
 * Get secret value from Secrets Manager
 */
export function getSecretValue({ accessKey, secretKey, region, secretArn, }) {
    return __awaiter(this, void 0, void 0, function* () {
        const client = new SecretsManagerClient({
            region,
            credentials: {
                accessKeyId: accessKey,
                secretAccessKey: secretKey,
            },
        });
        const params = {
            SecretId: secretArn,
        };
        let secret;
        const response = yield client.send(new GetSecretValueCommand(params));
        if (response.SecretString) {
            secret = response.SecretString;
        }
        else {
            throw new Error('Unable to get secret string!');
        }
        const unsafeJson = JSON.parse(secret);
        return {
            host: unsafeJson.host,
            username: unsafeJson.username,
            password: unsafeJson.password,
        };
    });
}
//# sourceMappingURL=getSecretValue.js.map