var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
import includes from 'lodash/includes';
import isEmpty from 'lodash/isEmpty';
import { SFNClient, GetExecutionHistoryCommand, } from '@aws-sdk/client-sfn';
// NOTE: AWS SFN SDK does not have these types as enumerations :(
// We consider any of these types as an execution failure event
// For all event types, see https://docs.aws.amazon.com/step-functions/latest/apireference/API_HistoryEvent.html
const executionFailureTypes = ['ExecutionAborted', 'ExecutionFailed', 'ExecutionTimedOut'];
export const isExecutionFailureEvent = (event) => {
    // We want to check if this event is a failure event that represents the whole execution.
    return includes(executionFailureTypes, event.type);
};
export const getExecutionFailureInfo = (event) => {
    // AWS SFN SDK has a property per event type
    // https://docs.aws.amazon.com/AWSJavaScriptSDK/v3/latest/clients/client-sfn/modules/historyevent.html
    var _a, _b, _c, _d, _e, _f, _g, _h, _j, _k, _l, _m;
    let cause = 'Unknown';
    let error = 'Unknown';
    switch (event.type) {
        case 'ExecutionAborted':
            cause = (_b = (_a = event.executionAbortedEventDetails) === null || _a === void 0 ? void 0 : _a.cause) !== null && _b !== void 0 ? _b : cause;
            error = (_d = (_c = event.executionAbortedEventDetails) === null || _c === void 0 ? void 0 : _c.error) !== null && _d !== void 0 ? _d : error;
            break;
        case 'ExecutionFailed':
            cause = (_f = (_e = event.executionFailedEventDetails) === null || _e === void 0 ? void 0 : _e.cause) !== null && _f !== void 0 ? _f : cause;
            error = (_h = (_g = event.executionFailedEventDetails) === null || _g === void 0 ? void 0 : _g.error) !== null && _h !== void 0 ? _h : error;
            break;
        case 'ExecutionTimedOut':
            cause = (_k = (_j = event.executionTimedOutEventDetails) === null || _j === void 0 ? void 0 : _j.cause) !== null && _k !== void 0 ? _k : cause;
            error = (_m = (_l = event.executionTimedOutEventDetails) === null || _l === void 0 ? void 0 : _l.error) !== null && _m !== void 0 ? _m : error;
            break;
    }
    return {
        cause,
        error,
    };
};
/**
 * Get the history of the execution of a step functions state machine
 */
export function getExecutionHistory({ accessKey, secretKey, region, executionArn, }) {
    var _a;
    return __awaiter(this, void 0, void 0, function* () {
        const cfnClient = new SFNClient({
            region,
            credentials: {
                accessKeyId: accessKey,
                secretAccessKey: secretKey,
            },
        });
        const params = {
            executionArn,
            includeExecutionData: false,
            maxResults: 1000,
            reverseOrder: true,
        };
        const events = [];
        let data;
        do {
            data = yield cfnClient.send(new GetExecutionHistoryCommand(params));
            params.nextToken = data.nextToken;
            if (!isEmpty(data.events)) {
                events.push(...((_a = data.events) !== null && _a !== void 0 ? _a : []));
            }
        } while (params.nextToken);
        return events;
    });
}
//# sourceMappingURL=getExecutionHistory.js.map