export interface CredentialsInput {
    accessKey: string;
    secretKey: string;
    region: string;
}
export declare enum CredentialsValidationErrorCode {
    NotAdmin = "NOT_ADMIN",
    InvalidKeys = "INVALID_KEYS",
    AccountMismatch = "ACCOUNT_MISMATCH",
    Unknown = "UNKNOWN"
}
export interface CredentialsValidationResult {
    accountId: string;
    userArn: string;
    userName?: string;
}
export declare class CredentialsValidationException extends Error {
    code: CredentialsValidationErrorCode;
    rootCause: Error | undefined;
    constructor(code: CredentialsValidationErrorCode, rootCause?: Error);
}
/**
 * Validates if the credentials are for an admin. If not, an exception is thrown.
 * Validating the credentials includes the following steps:
 * - Get the account id and user arn by calling caller identity
 * - Get the managed policies attached to the principal and ensure that one of them is AdministratorAccess
 *
 * If all checks out, this function returns the account id and the user name
 */
export declare function validateCredentials({ accessKey, secretKey, region, }: CredentialsInput): Promise<CredentialsValidationResult>;
